@@ -694,9 +694,11 @@ int miic::reconstruction::OrientTpl_LV_Deg_Propag(int NbTpl, int* Tpl,
       deg, maxTpl, maxscoreTpl);
 #endif  // _MY_PRINT_
 
-  delete (ProbArrowhead2);
-  delete (scoreTpl);
-  delete (orderTpl);
+  delete[] ProbArrowhead2;
+  delete[] scoreTpl;
+  delete[] logscoreTpl;
+  delete[] orderTpl;
+  delete[] scoresN;
 
   return 0;
 }
